==> ingdao-0.0.2.tar.gz: example/datasync/lib/ui/timesheet_screen.dart <==
import 'package:flutter/material.dart';
import '../datalayer/entity/tanktimesheet/tanktimesheetbean.dart';
import '../bloc/bloc_provider.dart';
import '../bloc/tanktimesheet_bloc.dart';
import '../bloc/tanktimesheet_query_bloc.dart';
import 'timesheet_save_screen.dart';

class TimesheetScreen extends StatelessWidget {
  final bool isFullScreenDialog;

  const TimesheetScreen({Key key, this.isFullScreenDialog = false}) : super(key: key);

  Widget _buildTxtSearchLocation(Function f) {
    return TextField(
      decoration: InputDecoration(
          border: OutlineInputBorder(),
          hintText: 'Enter a location'
        ),
        onChanged: (query) {f(query);},
    );    
  }

  Widget _buildResults(TanktimesheetQueryBloc bloc) {
    return StreamBuilder<List<TankTimesheetBean>>(
      stream: bloc.stream,
      builder: (context, snapshot) {
        final results = snapshot.data;
        if (results == null) {
          return Center(child: Text('Enter a location'));
        }
        if (results.isEmpty) {
          return Center(child: Text('No Results'));
        }
        return _buildSearchResults(results);
      }
    );
    //return Center(child: Text('Enter a location'));
  }

  Widget _buildSearchResults(List<TankTimesheetBean> results) {
    return ListView.separated(
      itemCount: results.length,
      separatorBuilder: (BuildContext context, int index) => Divider(),
      itemBuilder: (context, index) {
        final timesheet = results[index];
        return ListTile(
          title: Text("${timesheet.id} ${timesheet.active}"),
          subtitle: Text(timesheet.markOn != null ? timesheet.markOn.toString() : "NULL"),
          onTap: () {
            final bloc = BlocProvider.of<TanktimesheetQueryBloc>(context);
            Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => TimesheetSaveScreen(timesheet: timesheet, bloc: bloc)),
            );

            // final locationBloc = BlocProvider.of<LocationBloc>(context);
            // locationBloc.selectLocation(location);
            // if (isFullScreenDialog) {
            //   Navigator.of(context).pop();
            // }
          }
        );
      }
    );
  }

  @override
  Widget build(BuildContext context) {
    final bloc = TanktimesheetQueryBloc();
    return BlocProvider<TanktimesheetQueryBloc>(
      bloc: bloc,
      child: Scaffold(
      appBar: AppBar(
        actions: [
          IconButton(
            icon: Icon(Icons.add),
            onPressed: () {
              Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => TimesheetSaveScreen(bloc: bloc)),
              );
            },
          )
        ],
      ),
      body: Column(
        children: [
          Padding(
            padding: const EdgeInsets.all(10.0),
            child: _buildTxtSearchLocation((query) {
              if (query == 'Tank 1223')
                bloc.submitQuery(query);
            })
          ),
          Expanded(
            child: _buildResults(bloc)
          )
        ],
      )
    )
    );
  }


}

==> ingdao-0.0.19.tar.gz: example/datasync/lib/ui/timesheet_screen.dart <==
import 'package:flutter/material.dart';
import '../datalayer/entity/tanktimesheet/tanktimesheet.dart';
import '../bloc/bloc_provider.dart';
import '../bloc/tanktimesheet_bloc.dart';
import '../bloc/tanktimesheet_query_bloc.dart';
import 'timesheet_save_screen.dart';

class TimesheetScreen extends StatelessWidget {
  final bool isFullScreenDialog;

  const TimesheetScreen({Key key, this.isFullScreenDialog = false}) : super(key: key);

  Widget _buildTxtSearchLocation(Function f) {
    return TextField(
      decoration: InputDecoration(
          border: OutlineInputBorder(),
          hintText: 'Enter a location'
        ),
        onChanged: (query) {f(query);},
    );    
  }

  Widget _buildResults(TanktimesheetQueryBloc bloc) {
    return StreamBuilder<List<TankTimesheet>>(
      stream: bloc.stream,
      builder: (context, snapshot) {
        final results = snapshot.data;
        if (results == null) {
          return Center(child: Text('Enter a location'));
        }
        if (results.isEmpty) {
          return Center(child: Text('No Results'));
        }
        return _buildSearchResults(results);
      }
    );
    //return Center(child: Text('Enter a location'));
  }

  Widget _buildSearchResults(List<TankTimesheet> results) {
    return ListView.separated(
      itemCount: results.length,
      separatorBuilder: (BuildContext context, int index) => Divider(),
      itemBuilder: (context, index) {
        final timesheet = results[index];
        return ListTile(
          title: Text("${timesheet.id} ${timesheet.active}"),
          subtitle: Text(timesheet.markOn != null ? timesheet.markOn.toString() : "NULL"),
          onTap: () {
            final bloc = BlocProvider.of<TanktimesheetQueryBloc>(context);
            Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => TimesheetSaveScreen(timesheet: timesheet, bloc: bloc)),
            );

            // final locationBloc = BlocProvider.of<LocationBloc>(context);
            // locationBloc.selectLocation(location);
            // if (isFullScreenDialog) {
            //   Navigator.of(context).pop();
            // }
          }
        );
      }
    );
  }

  @override
  Widget build(BuildContext context) {
    final bloc = TanktimesheetQueryBloc();
    return BlocProvider<TanktimesheetQueryBloc>(
      bloc: bloc,
      child: Scaffold(
      appBar: AppBar(
        actions: [
          IconButton(
            icon: Icon(Icons.add),
            onPressed: () {
              Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => TimesheetSaveScreen(bloc: bloc)),
              );
            },
          )
        ],
      ),
      body: Column(
        children: [
          Padding(
            padding: const EdgeInsets.all(10.0),
            child: _buildTxtSearchLocation((query) {
              if (query == 'Tank 1223')
                bloc.submitQuery(query);
            })
          ),
          Expanded(
            child: _buildResults(bloc)
          )
        ],
      )
    )
    );
  }


}
